(landmark-tutorials)=

# Landmark-based Morphometrics Tutorials

Tutorials for the :mod:`ktch.landmark` module.

```{eval-rst}
.. toctree::
    :maxdepth: 1

    ./generalized_Procrustes_analysis
    ./gpa_from_tps
    ./gpa_with_semilandmarks
    ./thin_plate_spline
```
